==> vtk-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkAbstractImageInterpolator.java <==
// java wrapper for vtkAbstractImageInterpolator object
//

package vtk;
import vtk.*;

public class vtkAbstractImageInterpolator extends vtkObject
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(vtkDataObject id0);
  public void Initialize(vtkDataObject id0)
    { Initialize_2(id0); }

  private native void ReleaseData_3();
  public void ReleaseData()
    { ReleaseData_3(); }

  private native void DeepCopy_4(vtkAbstractImageInterpolator id0);
  public void DeepCopy(vtkAbstractImageInterpolator id0)
    { DeepCopy_4(id0); }

  private native void Update_5();
  public void Update()
    { Update_5(); }

  private native double Interpolate_6(double id0,double id1,double id2,int id3);
  public double Interpolate(double id0,double id1,double id2,int id3)
    { return Interpolate_6(id0,id1,id2,id3); }

  private native void SetOutValue_7(double id0);
  public void SetOutValue(double id0)
    { SetOutValue_7(id0); }

  private native double GetOutValue_8();
  public double GetOutValue()
    { return GetOutValue_8(); }

  private native void SetTolerance_9(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_9(id0); }

  private native double GetTolerance_10();
  public double GetTolerance()
    { return GetTolerance_10(); }

  private native void SetComponentOffset_11(int id0);
  public void SetComponentOffset(int id0)
    { SetComponentOffset_11(id0); }

  private native int GetComponentOffset_12();
  public int GetComponentOffset()
    { return GetComponentOffset_12(); }

  private native void SetComponentCount_13(int id0);
  public void SetComponentCount(int id0)
    { SetComponentCount_13(id0); }

  private native int GetComponentCount_14();
  public int GetComponentCount()
    { return GetComponentCount_14(); }

  private native int ComputeNumberOfComponents_15(int id0);
  public int ComputeNumberOfComponents(int id0)
    { return ComputeNumberOfComponents_15(id0); }

  private native int GetNumberOfComponents_16();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_16(); }

  private native boolean CheckBoundsIJK_17(double id0[]);
  public boolean CheckBoundsIJK(double id0[])
    { return CheckBoundsIJK_17(id0); }

  private native void SetBorderMode_18(int id0);
  public void SetBorderMode(int id0)
    { SetBorderMode_18(id0); }

  private native void SetBorderModeToClamp_19();
  public void SetBorderModeToClamp()
    { SetBorderModeToClamp_19(); }

  private native void SetBorderModeToRepeat_20();
  public void SetBorderModeToRepeat()
    { SetBorderModeToRepeat_20(); }

  private native void SetBorderModeToMirror_21();
  public void SetBorderModeToMirror()
    { SetBorderModeToMirror_21(); }

  private native int GetBorderMode_22();
  public int GetBorderMode()
    { return GetBorderMode_22(); }

  private native String GetBorderModeAsString_23();
  public String GetBorderModeAsString()
    { return GetBorderModeAsString_23(); }

  private native void ComputeSupportSize_24(double id0[],int id1[]);
  public void ComputeSupportSize(double id0[],int id1[])
    { ComputeSupportSize_24(id0,id1); }

  private native boolean IsSeparable_25();
  public boolean IsSeparable()
    { return IsSeparable_25(); }

  private native double[] GetSpacing_26();
  public double[] GetSpacing()
    { return GetSpacing_26(); }

  private native double[] GetOrigin_27();
  public double[] GetOrigin()
    { return GetOrigin_27(); }

  private native int[]  GetExtent_28();
  public int[]  GetExtent()
    { return GetExtent_28(); }

  private native int[]  GetWholeExtent_29();
  public int[]  GetWholeExtent()
    { return GetWholeExtent_29(); }

  public vtkAbstractImageInterpolator() { super(); }

  public vtkAbstractImageInterpolator(long id) { super(id); }

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkAbstractImageInterpolator.java <==
// java wrapper for vtkAbstractImageInterpolator object
//

package vtk;
import vtk.*;

public class vtkAbstractImageInterpolator extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2(vtkDataObject id0);
  public void Initialize(vtkDataObject id0)
    { Initialize_2(id0); }

  private native void ReleaseData_3();
  public void ReleaseData()
    { ReleaseData_3(); }

  private native void DeepCopy_4(vtkAbstractImageInterpolator id0);
  public void DeepCopy(vtkAbstractImageInterpolator id0)
    { DeepCopy_4(id0); }

  private native void Update_5();
  public void Update()
    { Update_5(); }

  private native double Interpolate_6(double id0,double id1,double id2,int id3);
  public double Interpolate(double id0,double id1,double id2,int id3)
    { return Interpolate_6(id0,id1,id2,id3); }

  private native void SetOutValue_7(double id0);
  public void SetOutValue(double id0)
    { SetOutValue_7(id0); }

  private native double GetOutValue_8();
  public double GetOutValue()
    { return GetOutValue_8(); }

  private native void SetTolerance_9(double id0);
  public void SetTolerance(double id0)
    { SetTolerance_9(id0); }

  private native double GetTolerance_10();
  public double GetTolerance()
    { return GetTolerance_10(); }

  private native void SetComponentOffset_11(int id0);
  public void SetComponentOffset(int id0)
    { SetComponentOffset_11(id0); }

  private native int GetComponentOffset_12();
  public int GetComponentOffset()
    { return GetComponentOffset_12(); }

  private native void SetComponentCount_13(int id0);
  public void SetComponentCount(int id0)
    { SetComponentCount_13(id0); }

  private native int GetComponentCount_14();
  public int GetComponentCount()
    { return GetComponentCount_14(); }

  private native int ComputeNumberOfComponents_15(int id0);
  public int ComputeNumberOfComponents(int id0)
    { return ComputeNumberOfComponents_15(id0); }

  private native int GetNumberOfComponents_16();
  public int GetNumberOfComponents()
    { return GetNumberOfComponents_16(); }

  private native boolean CheckBoundsIJK_17(double id0[]);
  public boolean CheckBoundsIJK(double id0[])
    { return CheckBoundsIJK_17(id0); }

  private native void SetBorderMode_18(int id0);
  public void SetBorderMode(int id0)
    { SetBorderMode_18(id0); }

  private native void SetBorderModeToClamp_19();
  public void SetBorderModeToClamp()
    { SetBorderModeToClamp_19(); }

  private native void SetBorderModeToRepeat_20();
  public void SetBorderModeToRepeat()
    { SetBorderModeToRepeat_20(); }

  private native void SetBorderModeToMirror_21();
  public void SetBorderModeToMirror()
    { SetBorderModeToMirror_21(); }

  private native int GetBorderMode_22();
  public int GetBorderMode()
    { return GetBorderMode_22(); }

  private native String GetBorderModeAsString_23();
  public String GetBorderModeAsString()
    { return GetBorderModeAsString_23(); }

  private native void SetSlidingWindow_24(boolean id0);
  public void SetSlidingWindow(boolean id0)
    { SetSlidingWindow_24(id0); }

  private native void SlidingWindowOn_25();
  public void SlidingWindowOn()
    { SlidingWindowOn_25(); }

  private native void SlidingWindowOff_26();
  public void SlidingWindowOff()
    { SlidingWindowOff_26(); }

  private native boolean GetSlidingWindow_27();
  public boolean GetSlidingWindow()
    { return GetSlidingWindow_27(); }

  private native void ComputeSupportSize_28(double id0[],int id1[]);
  public void ComputeSupportSize(double id0[],int id1[])
    { ComputeSupportSize_28(id0,id1); }

  private native boolean IsSeparable_29();
  public boolean IsSeparable()
    { return IsSeparable_29(); }

  private native double[] GetSpacing_30();
  public double[] GetSpacing()
    { return GetSpacing_30(); }

  private native double[] GetOrigin_31();
  public double[] GetOrigin()
    { return GetOrigin_31(); }

  private native int[]  GetExtent_32();
  public int[]  GetExtent()
    { return GetExtent_32(); }

  private native void GetWholeExtent_33(int id0[]);
  public void GetWholeExtent(int id0[])
    { GetWholeExtent_33(id0); }

  public vtkAbstractImageInterpolator() { super(); }

  public vtkAbstractImageInterpolator(long id) { super(id); }

}
